==> gtkhtml-0.8.tar.gz: gtkhtml-0.8/src/gtkhtml-stream.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*  This file is part of the GtkHTML library.

    Copyright 1999, 2000 Helix Code, Inc.
    
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef _GTKHTML_STREAM_H
#define _GTKHTML_STREAM_H

#include "gtkhtml-types.h"

struct _GtkHTMLStream {
	GtkHTMLStreamWriteFunc write_func;
	GtkHTMLStreamCloseFunc close_func;
	gpointer user_data;
};


GtkHTMLStream *gtk_html_stream_new      (GtkHTML                *html,
					 GtkHTMLStreamWriteFunc  write_func,
					 GtkHTMLStreamCloseFunc  close_func,
					 gpointer                user_data);
void           gtk_html_stream_write    (GtkHTMLStream          *stream,
					 const gchar            *buffer,
					 size_t                  size);
void           gtk_html_stream_destroy  (GtkHTMLStream          *stream);
void           gtk_html_stream_close    (GtkHTMLStream          *stream,
					 GtkHTMLStreamStatus     status);

#endif /* _GTKHTML_STREAM_H */

==> gtkhtml-0.8.1.tar.gz: gtkhtml-0.8.1/src/gtkhtml-stream.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*  This file is part of the GtkHTML library.

    Copyright 1999, 2000 Helix Code, Inc.
    
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef _GTKHTML_STREAM_H
#define _GTKHTML_STREAM_H

#include "gtkhtml-types.h"

struct _GtkHTMLStream {
	GtkHTMLStreamWriteFunc write_func;
	GtkHTMLStreamCloseFunc close_func;
	gpointer user_data;
};


GtkHTMLStream *gtk_html_stream_new      (GtkHTML                *html,
					 GtkHTMLStreamWriteFunc  write_func,
					 GtkHTMLStreamCloseFunc  close_func,
					 gpointer                user_data);
void           gtk_html_stream_write    (GtkHTMLStream          *stream,
					 const gchar            *buffer,
					 size_t                  size);
void           gtk_html_stream_destroy  (GtkHTMLStream          *stream);
void           gtk_html_stream_close    (GtkHTMLStream          *stream,
					 GtkHTMLStreamStatus     status);
GtkHTMLStream *gtk_html_stream_ref      (GtkHTMLStream          *handle);
void           gtk_html_stream_unref    (GtkHTMLStream          *handle);


#endif /* _GTKHTML_STREAM_H */
